@@ -1,9 +1,12 @@
 import colorlog
 from .config import *
-from .data_model_import import DataModel
+from .data_model import DataModel
+from .simultan_utils import create_component
 from .template_tools import Template, TemplateParser
 from .geo_default_types import BaseGeometricLayer, BaseGeometricVertex, BaseGeometricEdge, BaseGeometricEdgeLoop, BaseGeometricFace, BaseGeometricVolume
 
+from .ParameterStructure.Components import SimComponent
+from .ParameterStructure.Parameters import SimParameter
 
 handler = colorlog.StreamHandler()
 formatter = colorlog.ColoredFormatter(
@@ -24,4 +27,4 @@ formatter = colorlog.ColoredFormatter(
 handler.setFormatter(formatter)
 
 logger = colorlog.getLogger('PySimultan')
-logger.addHandler(handler)
\ No newline at end of file
+logger.addHandler(handler)
