@@ -14,10 +14,9 @@ from typing import NewType, Union, Optional
 # from System import Array, Double
 
 from .ParameterStructure.Values import SimMultiValueBigTable, SimMultiValueBigTableHeader
-from .ParameterStructure.Instances import SimInstancePlacementGeometry
-from .ParameterStructure.Components import SimComponent
+from .ParameterStructure.Instances import SimInstancePlacementGeometry, SimInstanceType
 from .ParameterStructure.Parameters import SimParameter
-from .ParameterStructure.Components import SimSlot, SimSlotBase, SimChildComponentEntry, ComponentUtils
+from .ParameterStructure.Components import SimComponent, SimSlot, SimSlotBase, SimChildComponentEntry, ComponentUtils
 from .ParameterStructure.Algorithms.Components import ComponentManagement, ComponentMapping
 from .ParameterStructure.Assets import ContainedResourceFileEntry
 from .ParameterStructure.SimObjects import SimId
@@ -449,7 +448,7 @@ class SimultanObject(object, metaclass=MetaMock):
     def referenced_components(self):
         if self._referenced_components is None:
             if self._wrapped_obj is not None:
-                self._referenced_components = [self._template_parser.create_python_object(x.Reference) for x in self._wrapped_obj.ReferencedComponents.Items]
+                self._referenced_components = [self._template_parser.create_python_object(x.Target) for x in self._wrapped_obj.ReferencedComponents.Items]
         return self._referenced_components
 
     @property
@@ -553,7 +552,7 @@ class SimultanObject(object, metaclass=MetaMock):
             c_slot_extension = comp.ReferenceFunction.SlotExtension
 
             sc_df = sc_df.append(
-                pd.DataFrame(data={'comp': [self._template_parser.create_python_object(comp.Reference)],
+                pd.DataFrame(data={'comp': [self._template_parser.create_python_object(comp.Target)],
                                    'slot': [c_slot],
                                    'slot_extension': c_slot_extension,
                                    'comp_type': 1}),
@@ -726,7 +725,7 @@ class SimultanObject(object, metaclass=MetaMock):
 
         if component is None:
             if new_component is None:
-                return
+                pass
             if isinstance(new_component, SimultanObject):
                 self.add_component_reference(component=new_component,
                                              slot_name=slot_name,
@@ -743,7 +742,7 @@ class SimultanObject(object, metaclass=MetaMock):
 
             references = []
             for ref_comp in set(component._wrapped_obj.ReferencedBy):
-                ref = next((x for x in ref_comp.ReferencedComponents.Items if x.Reference == component._wrapped_obj), None)
+                ref = next((x for x in ref_comp.ReferencedComponents.Items if x.Target == component._wrapped_obj), None)
                 references.append(ref)
 
             new_sim_component = new_component
@@ -767,6 +766,9 @@ class SimultanObject(object, metaclass=MetaMock):
                         new_component.CurrentSlot = comp_ref.Slot.SlotBase
                         comp_ref.Component = new_component
 
+                elif new_component is None:
+                    self.remove_sub_component(component)
+
             # old component is reference
             elif self.slot_components.iloc[idx].comp_type == 1:
                 ref = next((x for x in self._wrapped_obj.ReferencedComponents.Items
@@ -774,7 +776,7 @@ class SimultanObject(object, metaclass=MetaMock):
                         x.ReferenceFunction.SlotExtension == slot_extension))), None)
                 if isinstance(new_component, SimultanObject):
                     new_sim_component = new_component._wrapped_obj
-                    ref.Reference = new_component._wrapped_obj
+                    ref.Target = new_component._wrapped_obj
                 elif isinstance(new_component, SimComponent):
                     self.remove_component_reference(component)
                     self.add_sub_component(new_component)
@@ -782,7 +784,7 @@ class SimultanObject(object, metaclass=MetaMock):
                     self.remove_component_reference(component)
 
             for ref in references:
-                ref.Reference = new_sim_component
+                ref.Target = new_sim_component
 
         # clear the cache of the attributes getter:
         getattr(self.__class__, key).fget.cache_clear()
@@ -884,7 +886,7 @@ class ReferenceList(UserList):
         if self._wrapped_obj is None:
             return
 
-        ref_components = [x.Reference for x in self._wrapped_obj.ReferencedComponents.Items]
+        ref_components = [x.Target for x in self._wrapped_obj.ReferencedComponents.Items]
         try:
             indices = sort_references(self._wrapped_obj.ReferencedComponents.Items)
             return [x for _, x in sorted(zip(indices, ref_components))]
@@ -966,7 +968,7 @@ class BuildInFace(SimultanObject):
     @property
     def geo_ids(self):
         geo_ids = []
-        for item in self._wrapped_obj.GeometryInstances.Items:
+        for item in self._wrapped_obj.Instances.Items:
 
             geom_placement = next(x for x in item.Placements.Items if isinstance(x, SimInstancePlacementGeometry))
 
@@ -996,14 +998,14 @@ class BuildInFace(SimultanObject):
 
     @property
     def construction(self):
-        obj = next((x.Reference for x in self._wrapped_obj.ReferencedComponents.Items if x.ReferenceFunction.SlotFull == 'Aufbau_0AG0'), None)
+        obj = next((x.Target for x in self._wrapped_obj.ReferencedComponents.Items if x.ReferenceFunction.SlotFull == 'Aufbau_0AG0'), None)
         return self._template_parser.create_python_object(obj)
 
     def get_geo_instances(self):
         try:
             geo_instances = []
 
-            for item in self._wrapped_obj.GeometryInstances.Items:
+            for item in self._wrapped_obj.Instances.Items:
 
                 if item.Placements.Items.__len__() == 0:
                     continue
@@ -1026,6 +1028,16 @@ class BuildInFace(SimultanObject):
             logger.error(f'BuildInFace {self.name}; {self.id}: Error while getting geo instances: {e}')
             return []
 
+    def associate_with_geometry(self, face):
+
+        try:
+            self.InstanceType = SimInstanceType.Entity3D
+        except Exception as e:
+            raise e
+
+        exch = face.geometry_model.template_parser.current_data_model.exch
+        exch.Associate(self, face._wrapped_obj)
+
 
 class BuildInVolume(SimultanObject):
 
