@@ -122,7 +122,7 @@ class Template(object):
 
                 simultan_base_list = [SimultanObject, UserList, ValueField]
 
-                if any(x in simultan_base_list for x in base.__bases__):
+                if any([issubclass(base, x) for x in simultan_base_list]):
                     bases = (base, )
                 else:
                     bases = (SimultanObject, ) + (base, )
@@ -163,6 +163,7 @@ class Template(object):
                           '_base': bases,
                           '_template_parser': self.template_parser,
                           '_slots': self.slots,
+                          '_synonyms': self.synonyms,
                           '_default_slot': self.default_slot}
 
         new_class_dict.update(self.get_properties())
@@ -185,7 +186,7 @@ class Template(object):
 
             syn = self.synonyms.get('prop', prop)
 
-            prop_dict[syn] = add_properties(prop, param_type=self.types.get(prop, None), slot=slot)
+            prop_dict[syn] = add_properties(prop, syn, param_type=self.types.get(prop, None), slot=slot)
 
         return prop_dict
 
@@ -438,10 +439,11 @@ class TemplateParser(object):
         return [self.create_python_object(x, template_name=template_name) for x in components]
 
 
-def add_properties(prop_name: str, param_type: str, slot=None) -> property:
+def add_properties(prop_name: str, syn_name: str, param_type: str, slot=None) -> property:
     """
     create property for a class
     :param prop_name: name of the property (str)
+    :param prop_name: name of the synonym (str)
     :param param_type: type of the property; if type == 'str': param.get_TextValue(); else: param.get_ValueCurrent() is returned
     :param slot: slot; default is None
     :return: property
@@ -526,7 +528,7 @@ def add_properties(prop_name: str, param_type: str, slot=None) -> property:
                                                slot_extension=slot_extension,
                                                alter_slot=True)
                     else:
-                        ref.Reference = value._wrapped_obj
+                        ref.Target = value._wrapped_obj
 
             # index does not exist
             elif idx.__len__() == 0:
